﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using TECIT.TBarCode;

namespace QRCodeGenerator
{
  public partial class Form1 : Form
  {
    public Form1 ()
    {
      InitializeComponent ();
    }

    public class ContactFields
    {
      public string Name;
      public string PreName; // vCard only
      public string Company;
      public string Phone;
      public string Email;
      public string Url;
      public string Address; // MeCard only
      public string Street;  // vCard only
      public string City;    // vCard only
      public string ZIP;     // vCard only
      public string Country; // vCard only
      public string Note;    // MeCard only
    }

    
    private string FormatData (string codeFormat, string data, ContactFields fields)
    {

      // add prefixes and apply contact data format
      switch (codeFormat)
      {
        case "URL":
          // make sure that data starts with http://
          if (!data.StartsWith ("http://"))
            data = "http://" + data;
          break;
        case "PHONE":
          data = String.Format ("tel:{0}", data);
          break;
        case "SMS":
          data = String.Format ("smsto:{0}", data);
          break;
        case "GEO":
          // not part of this sample!
          // the request to google API (get geo location for given address)
          // is described here
          // http://code.google.com/intl/en-us/apis/maps/documentation/geocoding/
          data = "geo:50.8885500,4.4391334";
          break;
        case "VCARD":
          if(fields != null)
            data = CreateVCardFormat(fields);
          break;
        case "MECARD":
          if (fields != null)
            data = CreateMeCardFormat (fields);
          break;
        // ****************************
        // add other formats as desired (Facebook, Twitter, etc)
        default:
          break;
      }

      return data;
    }

    private string CreateVCardFormat (ContactFields fields)
    {
      // for details to the VCARD format visit
      // http://en.wikipedia.org/wiki/VCard

      return "BEGIN:VCARD" + Environment.NewLine
        + "N:" + fields.PreName + ";" + fields.Name + Environment.NewLine
        + "TEL:" + fields.Phone + Environment.NewLine
        + "EMAIL:" + fields.Email + Environment.NewLine
        + "URL:" + fields.Url + Environment.NewLine
        + "ADR:;;" + fields.Street + ";" + fields.City + ";;" + fields.ZIP + ";" + fields.Country + Environment.NewLine
        + "END:VCARD";
    }

    private string CreateMeCardFormat (ContactFields fields)
    {
      return "MECARD:"
      + "N:" + fields.Name 
      + "ORG:" + fields.Company + ";"
      + "TEL:" + fields.Phone + ";"
      + "EMAIL:" + fields.Email + ";"
      + "ADR:" + fields.Address + ";"
      + "URL:" + fields.Url + ";"
      + "NOTE:" + fields.Note + ";;";
    }


    private void button1_Click (object sender, EventArgs e)
    {
      // create bar code object
      Barcode myQRCode = new Barcode ();

      // select bar code type
      myQRCode.BarcodeType = BarcodeType.QRCode;
      
      // select UTF-8 (used with mobile tagging)
      myQRCode.Codepage = CodePage.Utf_8;

      // select error correction level (usually low for mobile tagging)
      myQRCode.QRCode.ErrorCorrectionLevel = QRCodeErrorCorrectionLevel.Low;

      // code format selected by user (URL, SMS, PHONE,....)
      string codeFormat = cbCodeFormat.Text;       

      // url, sms, phone, ... user input
      string userData = txtData.Text;

      // contact info ... usually user input - in our sample we use a predefined value
      ContactFields userFields = new ContactFields () { Name = "Max", Company = "TEC-IT", Phone = "+43 7252 72720", Url = "http://www.tec-it.com" };

      // create data format and apply to bar code
      myQRCode.Data = FormatData (codeFormat, userData, userFields);

      // add quiet zone 4 modules / blocks (optional)
      myQRCode.QuietZoneTop = myQRCode.QuietZoneRight = myQRCode.QuietZoneLeft = myQRCode.QuietZoneBottom = 4;
      myQRCode.QuietZoneUnit = QuietZoneUnit.Modules;

      // set dpi to screen resolution 96 dpi (optional)
      float dpi = 96.0F;
      myQRCode.Dpi = dpi;

      // use a module width (block size) of 3 Pixels
      int scale = 3;
      
      // calculate size of bar code with scale factor
      Size optimalSize = myQRCode.CalculateOptimalBitmapSize (null, scale, scale);

      // adjust bounding rectangle with calculated size
      myQRCode.BoundingRectangle = new Rectangle(0,0, optimalSize.Width, optimalSize.Height);

      // to save simple B/W image you could use
      // myQRCode.Draw (fullPath, ImageType.Png);

      // adjust color from RGB value (optional)
      myQRCode.BarcodeColor = Color.FromArgb(192, 0, 0);

      // create full color bar code bitmap
      Bitmap barcodeImage = myQRCode.DrawBitmap ();
      barcodeImage.SetResolution (dpi, dpi);

      // create Png file name
      string fullPath = Path.GetTempPath() + Path.GetRandomFileName() + ".PNG";

      // save bar code bitmap to Png file
      barcodeImage.Save(fullPath, System.Drawing.Imaging.ImageFormat.Png);

      // load Png file to picture box
      pictureBox1.Load (fullPath);

      // delete bitmap file
      barcodeImage.Dispose ();
      File.Delete (fullPath);
    }

    private void Form1_Load (object sender, EventArgs e)
    {
      cbCodeFormat.SelectedIndex = 0;
    }
  }
}
